@@ -1,7 +1,7 @@
 package LINE::Bot::API;
 use strict;
 use warnings;
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 use JSON::XS;
 use URI;
@@ -137,13 +137,13 @@ LINE::Bot::API - SDK of the LINE Messaging API for Perl
 
 =head1 DESCRIPTION
 
-LINE::Bot::API is a client library to easily use the LINE Messaging API.
-You can create a bot which will run on the LINE App by registering your bot account.
-Your B<Messaging API> account can be created from L<LINE BUSINESS CENTER|https://business.line.me/>.
+LINE::Bot::API is a client library which lets you easily start using the LINE Messaging API.
+You can create a bot which runs on the LINE app by registering for a LINE Messaging API account.
+You can create a B<Messaging API> account from the L<LINE Business Center|https://business.line.me/>.
 
-You can find the B<Channel Secret> and B<Channel Access Token> on the Basic information page at L<LINE BUSINESS CENTER|https://business.line.me/>.
+You can find the B<Channel secret> and B<Channel access token> on the Basic information page on the Channel Console which you can access from the L<LINE Business Center|https://business.line.me/>.
 
-Please use this POD and LINE developers site's online documentation to enjoy your bot development work!
+Use this documentation and the LINE Developers documentation to get you started developing your own bot!
 
 =head1 METHODS
 
@@ -162,7 +162,7 @@ Send a reply message to a user, room or group.
 
     my $messages = LINE::Bot::API::Builder::SendMessage->new;
     $messages->add_text( text => 'Example reply text' );
-    
+
     my $ret = $bot->reply_message($reply_token, $messages->build);
     unless ($ret->is_success) {
         # error
@@ -172,10 +172,10 @@ Send a reply message to a user, room or group.
         }
     }
 
-You can get a C<reply_token> by a L<Webhook Event Object|https://devdocs.line.me/#webhook-event-object>.
-And see also C<parse_events_from_json($json)> method's document.
+You can get a C<reply_token> from a L<webhook event object|https://devdocs.line.me/#webhook-event-object>.
+See the documentation for the C<parse_events_from_json($json)> method.
 
-See also a online documentation.
+You can also see the online API reference documentation.
 L<https://devdocs.line.me/#reply-message>
 
 =head2 push_message($user_id|$room_id|$group_id, [ $message, ... ])
@@ -186,10 +186,10 @@ Send a push message to a user, room or group.
     $messages->add_text( text => 'Example push text' );
     $bot->push_message($user_id, $messages->build);
 
-You can get a C<user_id>, C<room_id> or C<group_id> by a L<Webhook Event Object|https://devdocs.line.me/#webhook-event-object>.
-And see also C<parse_events_from_json($json)> method's document.
+You can get a C<user_id>, C<room_id> or C<group_id> from a L<webhook event object|https://devdocs.line.me/#webhook-event-object>.
+See the documentation for the C<parse_events_from_json($json)> method.
 
-See also a online documentation.
+You can also see the online API reference documentation.
 L<https://devdocs.line.me/#push-message>
 
 =head2 validate_signature($json, $signature)
@@ -201,7 +201,7 @@ L<https://devdocs.line.me/#push-message>
 
 =head2 parse_events_from_json($json)
 
-Parse Webhook Event Objects and build L<LINE::Bot::API::Event> instances.
+Parse webhook event objects and build L<LINE::Bot::API::Event> instances.
 
     my $req = Plack::Request->new( ... );
     my $events = $bot->parse_events_from_json($req->content);
@@ -231,7 +231,7 @@ Parse Webhook Event Objects and build L<LINE::Bot::API::Event> instances.
 
 =head2 leave_room($room_id)
 
-Bot leaves a chat room.
+Bot leaves a room.
 
     $bot->leave_room($room_id);
 
@@ -240,12 +240,12 @@ And see also C<parse_events_from_json($json)> method's document.
 
 =head2 leave_group($group_id)
 
-Bot leaves a chat group.
+Bot leaves a group.
 
     $bot->leave_group($group_id);
 
-You can get a C<group_id> by a L<Webhook Event Object|https://devdocs.line.me/#webhook-event-object>.
-And see also C<parse_events_from_json($json)> method's document.
+You can get a C<group_id> from a L<webhook event object|https://devdocs.line.me/#webhook-event-object>.
+See the documentation for the C<parse_events_from_json($json)> method.
 
 =head2 get_message_content($message_id)
 
@@ -258,15 +258,15 @@ Get the original file which was sent by user.
         ...
     }
 
-You can get a C<message_id> by a L<Webhook Event Object|https://devdocs.line.me/#webhook-event-object>.
-And see also C<parse_events_from_json($json)> method's document.
+You can get a C<message_id> from a L<webhook event object|https://devdocs.line.me/#webhook-event-object>.
+See the documentation for the C<parse_events_from_json($json)> method.
 
-See also a online document.
+You can also see the online API reference documentation.
 L<https://devdocs.line.me/#get-content>
 
 =head2 get_profile($user_id)
 
-You can get the user profile information.
+Get user profile information.
 
     my $res = $bot->get_profile($user_id);
     if ($ret->is_success) {
@@ -276,12 +276,12 @@ You can get the user profile information.
         say $ret->status_message;
     }
 
-See also a online document.
+See the online API reference documentation.
 L<https://devdocs.line.me/#bot-api-get-profile>
 
-=head2 How to build for Send Message Object
+=head2 How to build a send message object
 
-When a C<LINE::Bot::API::Builder::SendMessage> class is used, it would be possible to build a send message object easily.
+When the C<LINE::Bot::API::Builder::SendMessage> class is used, it is possible easily to build a send message object.
 That class supports a fluent interface.
 
     my $messages = LINE::Bot::API::Builder::SendMessage->new(
@@ -293,7 +293,7 @@ That class supports a fluent interface.
     );
     $bot->reply_message($reply_token, $messages->build);
 
-See also a online documentation.
+See the online API reference documentation.
 L<https://devdocs.line.me/#send-message-object>
 
 =head3 Text type
@@ -363,10 +363,10 @@ Build a sticker type object.
     );
     $bot->reply_message($reply_token, $messages->build);
 
-=head3 Imagemap Type
+=head3 Imagemap type
 
 Build an imagemap type object.
-You can use a helper module for imagemap type.
+You can use a helper module for the imagemap type.
 
     my $imagemap = LINE::Bot::API::Builder::ImagemapMessage->new(
         base_url    => 'https://example.com/bot/images/rm001',
@@ -386,15 +386,15 @@ You can use a helper module for imagemap type.
         area_width  => 1040,
         area_height => 520,
     );
-    
+
     my $messages = LINE::Bot::API::Builder::SendMessage->new(
     )->add_imagemap($imagemap->build);
     $bot->reply_message($reply_token, $messages->build);
 
-=head3 Template Type
+=head3 Template type
 
 Build a template type object.
-You can use a helper module for template type.
+You can use a helper module for the template type.
 
 =head4 Buttons type
 
@@ -417,7 +417,7 @@ You can use a helper module for template type.
         label => 'message2',
         text  => 'message2',
     );
-    
+
     my $messages = LINE::Bot::API::Builder::SendMessage->new(
     )->add_template($buttons->build);
     $bot->reply_message($reply_token, $messages->build);
@@ -438,7 +438,7 @@ You can use a helper module for template type.
         label => 'uri',
         uri   => 'http://example.com/',
     );
-    
+
     my $messages = LINE::Bot::API::Builder::SendMessage->new(
     )->add_template($confirm->build);
     $bot->reply_message($reply_token, $messages->build);
@@ -466,7 +466,7 @@ You can use a helper module for template type.
         );
         $carousel->add_column($column->build);
     }
-    
+
     my $messages = LINE::Bot::API::Builder::SendMessage->new(
     )->add_template($carousel->build);
     $bot->reply_message($reply_token, $messages->build);
